carnold 2005/05/17 21:36:25
Modified: . build.properties.sample build.xml
src/slf4j/org/apache/log4j ULogger.java
src/slf4j/org/slf4j LoggerFactory.java
Log:
Bug 34883: SLF4J support updated for beta3 (o.s.Logger instead of o.s.ULogger)
Revision Changes Path
1.25 +1 -1 logging-log4j/build.properties.sample
Index: build.properties.sample
===================================================================
RCS file: /home/cvs/logging-log4j/build.properties.sample,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- build.properties.sample 12 May 2005 03:18:30 -0000 1.24
+++ build.properties.sample 18 May 2005 04:36:25 -0000 1.25
@@ -29,7 +29,7 @@
servlet-api.jar=${lib.home.dir}/jakarta-tomcat-5.5.9/common/lib/servlet-api.jar
# SLF4J api
-slf4j-api.jar=${lib.home.dir}/slf4j-1.0-beta2/slf4j-nop.jar
+slf4j-api.jar=${lib.home.dir}/slf4j-1.0-beta3/slf4j-nop.jar
# The templates for the creation of the web-pages are inherited
# from the parent project.
1.158 +13 -14 logging-log4j/build.xml
Index: build.xml
===================================================================
RCS file: /home/cvs/logging-log4j/build.xml,v
retrieving revision 1.157
retrieving revision 1.158
diff -u -r1.157 -r1.158
--- build.xml 12 May 2005 04:53:13 -0000 1.157
+++ build.xml 18 May 2005 04:36:25 -0000 1.158
@@ -125,7 +125,7 @@
For an SLF4J enabled build:
ant jar -Dslf4j=true
- -Dslf4j-api.jar=../slf4j-1.0-beta2/slf4j-nop.jar
+ -Dslf4j-api.jar=../slf4j-1.0-beta3/slf4j-nop.jar
</echo>
</target>
@@ -228,7 +228,7 @@
<isset property="implement-slf4j"/>
<not>
<and>
- <available classname="org.slf4j.ULogger">
+ <available classname="org.slf4j.Logger">
<classpath refid="compile.classpath"/>
</available>
<available file="${slf4j-api.jar}"/>
@@ -242,12 +242,12 @@
Please make sure that "slf4j" is false or "slf4j-api.jar" property
in build.properties
file is set correctly.
- </fail>
-
- <condition property="slf4j.source.dir" value="src/slf4j">
- <isset property="implement-slf4j"/>
- </condition>
- <property name="slf4j.source.dir" value="src/no-slf4j"/>
+ </fail>
+
+ <condition property="slf4j.source.dir" value="src/slf4j">
+ <isset property="implement-slf4j"/>
+ </condition>
+ <property name="slf4j.source.dir" value="src/no-slf4j"/>
</target>
@@ -308,7 +308,6 @@
**/StressCategory.java,
**/doc-files/*,
${stem}/db/**,
- ${stem}/ULogger.java,
${stem}/test/serialization/**,
${stem}/net/SMTPAppender.java,
${stem}/net/JMS*.java,
@@ -554,7 +553,7 @@
<target name="slf4jExtract" depends="slf4jCheck" if="implement-slf4j">
<unjar src="${slf4j-api.jar}" dest="${javac.dest}">
<patternset>
- <include name="org/slf4j/ULogger.class"/>
+ <include name="org/slf4j/Logger.class"/>
</patternset>
</unjar>
<property name="slf4j.exclude.pattern" value="bogus.bogus"/>
@@ -669,10 +668,10 @@
doctitle="log4j version ${version}<br>API Specification"
windowtitle="Log4j Version ${version}"
header="<b>Log4j ${version}</b>"
- bottom="Copyright 2000-2005 Apache Software Foundation.">
- <sourcepath>
- <pathelement path="${java.source.dir}"/>
- <pathelement path="${slf4j.source.dir}"/>
+ bottom="Copyright 2000-2005 Apache Software Foundation.">
+ <sourcepath>
+ <pathelement path="${java.source.dir}"/>
+ <pathelement path="${slf4j.source.dir}"/>
</sourcepath>
<link href="http://java.sun.com/products/j2se/1.3/docs/api/"/>
1.2 +3 -3 logging-log4j/src/slf4j/org/apache/log4j/ULogger.java
Index: LoggerFactory.java
===================================================================
RCS file: /home/cvs/logging-log4j/src/slf4j/org/slf4j/LoggerFactory.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- LoggerFactory.java 12 May 2005 03:55:45 -0000 1.1
+++ LoggerFactory.java 18 May 2005 04:36:25 -0000 1.2
@@ -15,7 +15,6 @@
*/
package org.slf4j;
-import org.apache.log4j.Logger;
@@ -30,19 +29,19 @@
}
- static public ULogger getLogger(final String name) {
- return Logger.getLogger(name);
+ static public Logger getLogger(final String name) {
+ return org.apache.log4j.Logger.getLogger(name);
}
- static public ULogger getLogger(final String domainName, final String
subDomainName) {
- return Logger.getLogger(domainName);
+ static public Logger getLogger(final String domainName, final String
subDomainName) {
+ return org.apache.log4j.Logger.getLogger(domainName);
}
- static public ULogger getLogger(final Class clazz) {
- return Logger.getLogger(clazz.getName());
+ static public Logger getLogger(final Class clazz) {
+ return org.apache.log4j.Logger.getLogger(clazz.getName());
}
- static public ULogger getLogger(final Class clazz, final String
subDomainName) {
- return Logger.getLogger(clazz.getName());
+ static public Logger getLogger(final Class clazz, final String
subDomainName) {
+ return org.apache.log4j.Logger.getLogger(clazz.getName());
}
}
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
Index: ULogger.java
===================================================================
RCS file: /home/cvs/logging-log4j/src/slf4j/org/apache/log4j/ULogger.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ULogger.java 12 May 2005 03:55:45 -0000 1.1
+++ ULogger.java 18 May 2005 04:36:25 -0000 1.2
@@ -18,11 +18,11 @@
/**
* A proxy for org.slf4j.ULogger. In slf4j implementing builds, this
* interface will extend org.slf4j.ULogger and add no additional methods.
*
* @author Ceki Gülcü
* @author Curt Arnold
*/
- public interface ULogger extends org.slf4j.ULogger {
+ public interface ULogger extends org.slf4j.Logger {
}
1.2 +8 -9 logging-log4j/src/slf4j/org/slf4j/LoggerFactory.java
@@ -18,11 +18,11 @@
/**
- * A proxy for org.slf4j.ULogger. In slf4j implementing builds, this
- * interface will extend org.slf4j.ULogger and add no additional methods.
+ * A proxy for org.slf4j.Logger. In slf4j implementing builds, this
+ * interface will extend org.slf4j.Logger and add no additional methods.
*
* @author Ceki Gülcü